@@ -9,13 +9,40 @@ use Carp;
 use vars qw($VERSION);
 $VERSION = $Mail::Builder::VERSION;
 
-# -------------------------------------------------------------
-sub new
-# Type: Constructor
-# Parameters: PATH[,ID]
-# Returnvalue: Object
-# -------------------------------------------------------------
-{
+=head1 NAME
+
+Mail::Builder::Image - Helper module for handling inline images
+
+=head1 SYNOPSIS
+
+  use Mail::Builder;
+  
+  my $image = Mail::Builder::Image('/home/guybrush/invitation.gif');
+  # Change CID
+  $image->id('invitation_location');
+  
+  # In the e-mail body
+  <img src="cid:invitation_location" alt=""/>
+  
+=head1 DESCRIPTION
+
+This is a simple module for handling inline images. The module needs the path 
+to the file and optional an id which can be used to reference the file from
+within the e-mail text.
+
+=head1 METHODS
+
+=head2 Constructor
+
+=head3 new
+
+ Mail::Builder::Image->new(PATH[,REFERENCE ID]);
+
+Simple constructor
+
+=cut
+
+sub new {
 	my $class = shift;
 	
 	my $obj = bless {
@@ -31,13 +58,78 @@ sub new
 	return $obj;
 }
 
-# -------------------------------------------------------------
-sub id
-# Type: Accessor
-# Parameters: Filename
-# Returnvalue: Mime::Entity
-# -------------------------------------------------------------
-{
+=head2 Public Methods
+
+=head3 serialize
+
+Returns the image as a MIME::Entity object. 
+
+=cut
+
+sub serialize {
+    my $obj = shift;
+    return $obj->{'cache'} if (defined $obj->{'cache'});
+    
+    unless ($obj->{'id'}) {
+        $obj->{'id'} = $obj->{'path'};
+        $obj->{'id'} =~ s/(^[\/]+)$/$1/;
+        $obj->{'id'} =~ s/^(.+)\.(JPE?G|GIF|PNG)$/$1/i;
+    }
+    
+    $obj->{'cache'} = build MIME::Entity(
+        Disposition     => 'inline',
+        Type            => qq[image/$obj->{'type'}],
+        Top             => 0,
+        Id              => qq[<$obj->{'id'}>],
+        Encoding        => 'base64',
+        Path            => $obj->{'path'},
+    );
+}
+
+=head3 compare
+
+ $obj->compare(OBJECT);
+ or
+ $obj->compare(PATH);
+
+Checks if two image objects contain the same file. Returns true 
+or false. The compare method does not check if the image id of the
+two objects are identical.
+
+Instead of a C<Mail::Builder::Image> object you can also pass a 
+scalar value representing the image path .
+
+=cut
+
+sub compare {
+    my $obj = shift;
+    my $compare = shift;
+    
+    return 0 unless ($compare);
+    
+    if (ref($compare)) {
+        return 0 unless $compare->isa(__PACKAGE__);
+        return ($compare->{path} eq $obj->{path}) ? 1:0;
+    } else {
+        return ($compare eq $obj->{path}) ? 1:0;  
+    }
+}
+
+
+
+=head2 Accessors
+
+=head3 id
+
+Accessor which takes/returns the id of the file. If no id is provided the 
+lowercase filename without the extension will be used as the id.
+
+The id is needed to reference the image in the e-mail body:
+ <img src="cid:invitation_location" alt=""/>
+
+=cut 
+
+sub id {
     my $obj = shift;
     if (@_) {
         $obj->{'id'} = shift;
@@ -46,13 +138,14 @@ sub id
     return $obj->{'id'};
 }
 
-# -------------------------------------------------------------
-sub path
-# Type: Accessor
-# Parameters: Filename
-# Returnvalue: Mime::Entity
-# -------------------------------------------------------------
-{
+=head3 path
+
+Accessor which takes/returns the path of the file on the filesystem. The file
+must be readable. Only .jpeg, .jpg, .gif and .png files may be added.
+
+=cut
+
+sub path {
     my $obj = shift;
     if (@_) {
         $obj->{'path'} = shift;
@@ -66,77 +159,12 @@ sub path
     return $obj->{'path'};
 }
 
-# -------------------------------------------------------------
-sub serialize
-# Type: Method
-# Parameters: -
-# Returnvalue: Mime::Entity
-# -------------------------------------------------------------
-{
-	my $obj = shift;
-	return $obj->{'cache'} if (defined $obj->{'cache'});
-	
-	unless ($obj->{'id'}) {
-		$obj->{'id'} = $obj->{'path'};
-		$obj->{'id'} =~ s/(^[\/]+)$/$1/;
-		$obj->{'id'} =~ s/^(.+)\.(JPE?G|GIF|PNG)$/$1/i;
-	}
-	
-	$obj->{'cache'} = build MIME::Entity(
-		Disposition		=> 'inline',
-		Type			=> qq[image/$obj->{'type'}],
-		Top				=> 0,
-		Id				=> qq[<$obj->{'id'}>],
-		Encoding		=> 'base64',
-		Path			=> $obj->{'path'},
-	);
-}
 
 1;
 
 __END__
 =pod
 
-=head1 NAME
-
-Mail::Builder::Image - Helper module for handling inline images
-
-=head1 SYNOPSIS
-
-  use Mail::Builder;
-  
-  my $image = Mail::Builder::Image('/home/guybrush/invitation.gif','invitation');
-  $image->id('invitation_location');
-  print $image->serialize;
-  
-=head1 DESCRIPTION
-
-This is a simple module for handling inline images. The module needs the path 
-to the file and optional an id which can be used to reference the file from
-within the e-mail text.
-
-=head1 USAGE
-
-=head2 new
-
-Simple constructor
-
- Mail::Builder::Image->new(PATH[,ID]);
-
-=head2 path
-
-Accessor which takes/returns the path of the file on the filesystem. The file
-must be readable.
-
-=head2 id
-
-Accessor which takes/returns the id of the file. If no id is provided the 
-lowercase filename without the extension will be used as an id.
-
-=head2 serialize
-
-Returns the image as a MIME::Entity object.
-
 =head1 AUTHOR
 
     Maroš Kollár
